# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/reporting/account_report/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/reporting/account_report/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2
from meshtrade.option.v1 import method_type_pb2 as meshtrade_dot_option_dot_v1_dot_method__type__pb2
from meshtrade.reporting.account_report.v1 import account_report_pb2 as meshtrade_dot_reporting_dot_account__report_dot_v1_dot_account__report__pb2
from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3meshtrade/reporting/account_report/v1/service.proto\x12%meshtrade.reporting.account_report.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a meshtrade/iam/role/v1/role.proto\x1a%meshtrade/option/v1/method_type.proto\x1a:meshtrade/reporting/account_report/v1/account_report.proto\x1a\x1dmeshtrade/type/v1/token.proto\"\xea\x01\n\x17GetAccountReportRequest\x12%\n\x0e\x61\x63\x63ount_number\x18\x01 \x01(\tR\raccountNumber\x12.\n\x04\x66rom\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x66rom\x12*\n\x02to\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02to\x12L\n\x15reporting_asset_token\x18\x04 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenR\x13reportingAssetToken\"\xdd\x03\n\x1cGetExcelAccountReportRequest\x12\x90\x01\n\x0e\x61\x63\x63ount_number\x18\x01 \x01(\tBi\xbaHfr\x0f\x10\x01\x32\x0b^[0-9]{1,}$\xba\x01R\n\x17\x61\x63\x63ount_number.required\x12\x1a\x61\x63\x63ount_number is required\x1a\x1bthis.matches(\'^[0-9]{1,}$\')R\raccountNumber\x12q\n\x04\x66rom\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampBA\xbaH>\xba\x01;\n\rfrom.required\x12\x1c\'from\' timestamp is required\x1a\x0cthis != nullR\x04\x66rom\x12i\n\x02to\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB=\xbaH:\xba\x01\x37\n\x0bto.required\x12\x1a\'to\' timestamp is required\x1a\x0cthis != nullR\x02to\x12L\n\x15reporting_asset_token\x18\x04 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenR\x13reportingAssetToken\"B\n\x1dGetExcelAccountReportResponse\x12!\n\x0c\x65xcel_base64\x18\x01 \x01(\tR\x0b\x65xcelBase642\xee\x02\n\x14\x41\x63\x63ountReportService\x12\x9c\x01\n\x10GetAccountReport\x12>.meshtrade.reporting.account_report.v1.GetAccountReportRequest\x1a\x34.meshtrade.reporting.account_report.v1.AccountReport\"\x12\xa0\xb5\x18\x01\xaa\xb5\x18\n\n\x08\x80\x9b\xee\x02\x81\x9b\xee\x02\x12\xb6\x01\n\x15GetExcelAccountReport\x12\x43.meshtrade.reporting.account_report.v1.GetExcelAccountReportRequest\x1a\x44.meshtrade.reporting.account_report.v1.GetExcelAccountReportResponse\"\x12\xa0\xb5\x18\x01\xaa\xb5\x18\n\n\x08\x80\x9b\xee\x02\x81\x9b\xee\x02\x42x\n,co.meshtrade.api.reporting.account_report.v1ZHgithub.com/meshtrade/api/go/reporting/account_report/v1;account_reportv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.reporting.account_report.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,co.meshtrade.api.reporting.account_report.v1ZHgithub.com/meshtrade/api/go/reporting/account_report/v1;account_reportv1'
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['account_number']._loaded_options = None
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['account_number']._serialized_options = b'\272Hfr\017\020\0012\013^[0-9]{1,}$\272\001R\n\027account_number.required\022\032account_number is required\032\033this.matches(\'^[0-9]{1,}$\')'
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['from']._loaded_options = None
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['from']._serialized_options = b'\272H>\272\001;\n\rfrom.required\022\034\'from\' timestamp is required\032\014this != null'
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['to']._loaded_options = None
  _globals['_GETEXCELACCOUNTREPORTREQUEST'].fields_by_name['to']._serialized_options = b'\272H:\272\0017\n\013to.required\022\032\'to\' timestamp is required\032\014this != null'
  _globals['_ACCOUNTREPORTSERVICE'].methods_by_name['GetAccountReport']._loaded_options = None
  _globals['_ACCOUNTREPORTSERVICE'].methods_by_name['GetAccountReport']._serialized_options = b'\240\265\030\001\252\265\030\n\n\010\200\233\356\002\201\233\356\002'
  _globals['_ACCOUNTREPORTSERVICE'].methods_by_name['GetExcelAccountReport']._loaded_options = None
  _globals['_ACCOUNTREPORTSERVICE'].methods_by_name['GetExcelAccountReport']._serialized_options = b'\240\265\030\001\252\265\030\n\n\010\200\233\356\002\201\233\356\002'
  _globals['_GETACCOUNTREPORTREQUEST']._serialized_start=321
  _globals['_GETACCOUNTREPORTREQUEST']._serialized_end=555
  _globals['_GETEXCELACCOUNTREPORTREQUEST']._serialized_start=558
  _globals['_GETEXCELACCOUNTREPORTREQUEST']._serialized_end=1035
  _globals['_GETEXCELACCOUNTREPORTRESPONSE']._serialized_start=1037
  _globals['_GETEXCELACCOUNTREPORTRESPONSE']._serialized_end=1103
  _globals['_ACCOUNTREPORTSERVICE']._serialized_start=1106
  _globals['_ACCOUNTREPORTSERVICE']._serialized_end=1472
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from meshtrade.reporting.account_report.v1 import account_report_pb2 as meshtrade_dot_reporting_dot_account__report_dot_v1_dot_account__report__pb2
from meshtrade.reporting.account_report.v1 import service_pb2 as meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2


class AccountReportServiceStub(object):
    """
    AccountReportService manages comprehensive account activity report generation and export.

    This service allows clients to retrieve structured account reports containing
    income entries, fee transactions, and trading statements, as well as download
    them as Excel files. Reports are generated for a specified account over a
    given time range with all values denominated in the account's reporting currency.

    All operations require Reporting domain permissions and operate within
    the authenticated group context.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAccountReport = channel.unary_unary(
                '/meshtrade.reporting.account_report.v1.AccountReportService/GetAccountReport',
                request_serializer=meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetAccountReportRequest.SerializeToString,
                response_deserializer=meshtrade_dot_reporting_dot_account__report_dot_v1_dot_account__report__pb2.AccountReport.FromString,
                _registered_method=True)
        self.GetExcelAccountReport = channel.unary_unary(
                '/meshtrade.reporting.account_report.v1.AccountReportService/GetExcelAccountReport',
                request_serializer=meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetExcelAccountReportRequest.SerializeToString,
                response_deserializer=meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetExcelAccountReportResponse.FromString,
                _registered_method=True)


class AccountReportServiceServicer(object):
    """
    AccountReportService manages comprehensive account activity report generation and export.

    This service allows clients to retrieve structured account reports containing
    income entries, fee transactions, and trading statements, as well as download
    them as Excel files. Reports are generated for a specified account over a
    given time range with all values denominated in the account's reporting currency.

    All operations require Reporting domain permissions and operate within
    the authenticated group context.
    """

    def GetAccountReport(self, request, context):
        """
        Retrieves a structured account report for the given account, within the given time range
        denominated in the given reporting asset token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExcelAccountReport(self, request, context):
        """
        Retrieves a structured account report for the given account, within the given time range
        denominated in the given reporting asset token, exported to an Excel file that can be downloaded.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AccountReportServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAccountReport': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountReport,
                    request_deserializer=meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetAccountReportRequest.FromString,
                    response_serializer=meshtrade_dot_reporting_dot_account__report_dot_v1_dot_account__report__pb2.AccountReport.SerializeToString,
            ),
            'GetExcelAccountReport': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExcelAccountReport,
                    request_deserializer=meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetExcelAccountReportRequest.FromString,
                    response_serializer=meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetExcelAccountReportResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'meshtrade.reporting.account_report.v1.AccountReportService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('meshtrade.reporting.account_report.v1.AccountReportService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AccountReportService(object):
    """
    AccountReportService manages comprehensive account activity report generation and export.

    This service allows clients to retrieve structured account reports containing
    income entries, fee transactions, and trading statements, as well as download
    them as Excel files. Reports are generated for a specified account over a
    given time range with all values denominated in the account's reporting currency.

    All operations require Reporting domain permissions and operate within
    the authenticated group context.
    """

    @staticmethod
    def GetAccountReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.reporting.account_report.v1.AccountReportService/GetAccountReport',
            meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetAccountReportRequest.SerializeToString,
            meshtrade_dot_reporting_dot_account__report_dot_v1_dot_account__report__pb2.AccountReport.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetExcelAccountReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.reporting.account_report.v1.AccountReportService/GetExcelAccountReport',
            meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetExcelAccountReportRequest.SerializeToString,
            meshtrade_dot_reporting_dot_account__report_dot_v1_dot_service__pb2.GetExcelAccountReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
